@@ -171,10 +171,10 @@ def rabbitmq(request, tmpdir):
     rabbit_conf = open(request.config.getvalue('rabbit_conf')).readlines()
     rabbit_conf = dict(line[:-1].split('=') for line in rabbit_conf)
 
-    rabbit_conf['RABBITMQ_LOG_BASE'] = str(tmpdir)
-    rabbit_conf['RABBITMQ_MNESIA_BASE'] = str(tmpdir)
+    rabbit_conf['RABBITMQ_LOG_BASE'] = str(tmpdir)[:64]
+    rabbit_conf['RABBITMQ_MNESIA_BASE'] = str(tmpdir)[:64]
 
-    # setup enviroment variables
+    # setup environment variables
     for name, value in rabbit_conf.items():
         # for new versions of rabbitmq-server:
         os.environ[name] = value
